import { Image, Layout, Dropdown, Space, Typography } from 'antd'
import type { MenuProps } from 'antd';
import Logo from '../../assets/png/xbox.png'
import '../../styles/headerXbox.scss'
import { DownOutlined, LoginOutlined, LogoutOutlined, UserOutlined } from '@ant-design/icons';
import { IHeaderXbox } from '../../interfaces/headerXbox';

const {Header} = Layout

const HeaderXbox = ({onClick, isUser}: IHeaderXbox) => {
    const onClickHandler: MenuProps['onClick'] = ({ key }) => {
        onClick(key)
    };

    const items: MenuProps['items'] = [
        {
          label: isUser ? null : 
          (
            <Space>
                <LoginOutlined />
                Login
            </Space>
          ),
          key: 'login',
        },
        {
          label: !isUser ? null :
          (
            <Space>
                <LogoutOutlined />
                Logout
            </Space>
          ),
          key: 'logout',
        },
    ];

    return (
        <Header className='HeaderXbox'>
            <Image 
                src={Logo} 
                width={100} 
                height={'70%'}
                preview={false}
            />

            <Dropdown menu={{ items, onClick: onClickHandler }}>
                <Space className='cursor'>
                    <Typography.Title style={{display: !isUser ? 'none' : 'block', color: 'white', margin: 0}}>
                        {localStorage.getItem('username')}
                    </Typography.Title>

                    <UserOutlined style={{color: 'rgba(141, 216, 61, 1)'}}/>
                    <Typography.Text style={{color: 'rgba(255, 255, 255, 0.5)'}}>
                        My XBOX
                    </Typography.Text>
                    <DownOutlined style={{color: 'rgba(141, 216, 61, 1)'}}/>
                </Space>
            </Dropdown>
        </Header>
  )
}

export default HeaderXbox